AUDIT: r21596 - gnucash/trunk/src/optional/python-bindings - Spelling fixes in doxygen comments

Geert Janssens gjanssens at code.gnucash.org
Sun Nov 20 04:34:45 EST 2011


Author: gjanssens
Date: 2011-11-20 04:34:45 -0500 (Sun, 20 Nov 2011)
New Revision: 21596
Trac: http://svn.gnucash.org/trac/changeset/21596

Modified:
   gnucash/trunk/src/optional/python-bindings/gnucash_core.i
   gnucash/trunk/src/optional/python-bindings/gnucash_core.py
Log:
Spelling fixes in doxygen comments
BP

Modified: gnucash/trunk/src/optional/python-bindings/gnucash_core.i
===================================================================
--- gnucash/trunk/src/optional/python-bindings/gnucash_core.i	2011-11-20 09:34:23 UTC (rev 21595)
+++ gnucash/trunk/src/optional/python-bindings/gnucash_core.i	2011-11-20 09:34:45 UTC (rev 21596)
@@ -186,7 +186,7 @@
 
 %include <gnc-lot.h>
 
-//business-core includes
+//core business includes
 %include <gncOwner.h>
 %include <gncCustomer.h>
 %include <gncEmployee.h>

Modified: gnucash/trunk/src/optional/python-bindings/gnucash_core.py
===================================================================
--- gnucash/trunk/src/optional/python-bindings/gnucash_core.py	2011-11-20 09:34:23 UTC (rev 21595)
+++ gnucash/trunk/src/optional/python-bindings/gnucash_core.py	2011-11-20 09:34:45 UTC (rev 21596)
@@ -61,11 +61,11 @@
     """A GnuCash book editing session
 
     To commit changes to the session you may need to call save,
-    (this is allways the case with the file backend).
+    (this is always the case with the file backend).
 
     When you're down with a session you may need to call end()
 
-    Every Session has a Book in the book attribute, which you'll definetely
+    Every Session has a Book in the book attribute, which you'll definitely
     be interested in, as every GnuCash entity (Transaction, Split, Vendor,
     Invoice..) is associated with a particular book where it is stored.
     """
@@ -157,7 +157,7 @@
     the book via the book property, 'my_session.book'
 
     If you would like to create a Book without any backing storage, call the
-    Book constructor wihout any parameters, 'Book()'. You can later merge
+    Book constructor without any parameters, 'Book()'. You can later merge
     such a book into a book with actual store by using merge_init.
 
     Methods of interest
@@ -324,11 +324,11 @@
 class GncCommodity(GnuCashCoreClass): pass
 
 class GncCommodityTable(GnuCashCoreClass):
-    """A CommodityTable provides a way to store and lookup commoditys.
-    Commoditys are primarily currencies, but other tradable things such as
-    stocks, mutual funds, and material substances are posible.
+    """A CommodityTable provides a way to store and lookup commodities.
+    Commodities are primarily currencies, but other tradable things such as
+    stocks, mutual funds, and material substances are possible.
 
-    Users of this library should not create thier own CommodityTable, instead
+    Users of this library should not create their own CommodityTable, instead
     the get_table method from the Book class should be used.
 
     This table is automatically populated with the GnuCash default commodity's



More information about the gnucash-changes mailing list